==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/plugins/page-structure/components/item-configuration-panels/FragmentStylesPanel.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/plugins/page-structure/components/item-configuration-panels/FragmentStylesPanel", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/icon', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../../app/config/constants/fragmentConfigurationRoles', '../../../../app/config/constants/freemarkerFragmentEntryProcessor', '../../../../app/config/constants/viewportSizes', '../../../../app/config/index', '../../../../app/selectors/selectSegmentsExperienceId', '../../../../app/store/index', '../../../../app/thunks/updateFragmentConfiguration', '../../../../app/utils/getResponsiveConfig', '../../../../prop-types/index', './CommonStyles', './FieldSet'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.FragmentStylesPanel = void 0;

    var _icon = _interopRequireDefault(require("@frontend-taglib-clay$clayui/icon"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _fragmentConfigurationRoles = require("../../../../app/config/constants/fragmentConfigurationRoles");

    var _freemarkerFragmentEntryProcessor = require("../../../../app/config/constants/freemarkerFragmentEntryProcessor");

    var _viewportSizes = require("../../../../app/config/constants/viewportSizes");

    var _index = require("../../../../app/config/index");

    var _selectSegmentsExperienceId = _interopRequireDefault(require("../../../../app/selectors/selectSegmentsExperienceId"));

    var _index2 = require("../../../../app/store/index");

    var _updateFragmentConfiguration = _interopRequireDefault(require("../../../../app/thunks/updateFragmentConfiguration"));

    var _getResponsiveConfig = require("../../../../app/utils/getResponsiveConfig");

    var _index3 = require("../../../../prop-types/index");

    var _CommonStyles = require("./CommonStyles");

    var _FieldSet = require("./FieldSet");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    var FragmentStylesPanel = function FragmentStylesPanel(_ref) {
      var item = _ref.item;
      var dispatch = (0, _index2.useDispatch)();
      var availableViewportSizes = _index.config.availableViewportSizes;
      var fragmentEntryLink = (0, _index2.useSelectorCallback)(function (state) {
        return state.fragmentEntryLinks[item.config.fragmentEntryLinkId];
      }, [item.config.fragmentEntryLinkId]);
      var segmentsExperienceId = (0, _index2.useSelector)(_selectSegmentsExperienceId["default"]);
      var selectedViewportSize = (0, _index2.useSelector)(function (state) {
        return state.selectedViewportSize;
      });
      var viewportSize = availableViewportSizes[selectedViewportSize];
      var itemConfig = (0, _getResponsiveConfig.getResponsiveConfig)(item.config, selectedViewportSize);
      var onCustomStyleValueSelect = (0, _react.useCallback)(function (name, value) {
        var configurationValues = getConfigurationValues(fragmentEntryLink);

        var nextConfigurationValues = _objectSpread({}, configurationValues, _defineProperty({}, name, value));

        dispatch((0, _updateFragmentConfiguration["default"])({
          configurationValues: nextConfigurationValues,
          fragmentEntryLink: fragmentEntryLink,
          segmentsExperienceId: segmentsExperienceId
        }));
      }, [dispatch, fragmentEntryLink, segmentsExperienceId]);
      return _react["default"].createElement(_react["default"].Fragment, null, _react["default"].createElement("p", {
        className: "page-editor__row-styles-panel__viewport-label"
      }, _react["default"].createElement(_icon["default"], {
        className: "mr-2",
        symbol: viewportSize.icon
      }), viewportSize.label), selectedViewportSize === _viewportSizes.VIEWPORT_SIZES.desktop && _react["default"].createElement(CustomStyles, {
        fragmentEntryLink: fragmentEntryLink,
        onValueSelect: onCustomStyleValueSelect
      }), _react["default"].createElement(_CommonStyles.CommonStyles, {
        commonStylesValues: itemConfig.styles,
        item: item
      }));
    };

    exports.FragmentStylesPanel = FragmentStylesPanel;

    var CustomStyles = function CustomStyles(_ref2) {
      var _fragmentEntryLink$co, _fragmentEntryLink$co2;

      var fragmentEntryLink = _ref2.fragmentEntryLink,
          onValueSelect = _ref2.onValueSelect;
      var fieldSets = (_fragmentEntryLink$co = fragmentEntryLink.configuration) === null || _fragmentEntryLink$co === void 0 ? void 0 : (_fragmentEntryLink$co2 = _fragmentEntryLink$co.fieldSets) === null || _fragmentEntryLink$co2 === void 0 ? void 0 : _fragmentEntryLink$co2.filter(function (fieldSet) {
        return fieldSet.configurationRole === _fragmentConfigurationRoles.FRAGMENT_CONFIGURATION_ROLES.style;
      });
      return (fieldSets === null || fieldSets === void 0 ? void 0 : fieldSets.length) ? _react["default"].createElement("div", {
        className: "page-editor__page-structure__section__custom-styles"
      }, _react["default"].createElement("h1", {
        className: "sr-only"
      }, Liferay.Language.get('custom-styles')), fieldSets.map(function (fieldSet, index) {
        return _react["default"].createElement(_FieldSet.FieldSet, {
          fields: fieldSet.fields,
          key: index,
          label: fieldSet.label,
          onValueSelect: onValueSelect,
          values: getConfigurationValues(fragmentEntryLink)
        });
      })) : null;
    };

    function getConfigurationValues(fragmentEntryLink) {
      return _objectSpread({}, fragmentEntryLink.defaultConfigurationValues, {}, fragmentEntryLink.editableValues[_freemarkerFragmentEntryProcessor.FREEMARKER_FRAGMENT_ENTRY_PROCESSOR]);
    }
    //# sourceMappingURL=FragmentStylesPanel.js.map
  }
});
//# sourceMappingURL=FragmentStylesPanel.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/plugins/page-structure/components/item-configuration-panels/FragmentStylesPanel.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/plugins/page-structure/components/item-configuration-panels/FragmentStylesPanel", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/icon', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react', '../../../../app/config/constants/fragmentConfigurationRoles', '../../../../app/config/constants/freemarkerFragmentEntryProcessor', '../../../../app/config/constants/viewportSizes', '../../../../app/config/index', '../../../../app/selectors/selectSegmentsExperienceId', '../../../../app/store/index', '../../../../app/thunks/updateFragmentConfiguration', '../../../../app/utils/getResponsiveConfig', '../../../../prop-types/index', './CommonStyles', './FieldSet'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.FragmentStylesPanel = void 0;

    var _icon = _interopRequireDefault(require("@frontend-taglib-clay$clayui/icon"));

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    var _fragmentConfigurationRoles = require("../../../../app/config/constants/fragmentConfigurationRoles");

    var _freemarkerFragmentEntryProcessor = require("../../../../app/config/constants/freemarkerFragmentEntryProcessor");

    var _viewportSizes = require("../../../../app/config/constants/viewportSizes");

    var _index = require("../../../../app/config/index");

    var _selectSegmentsExperienceId = _interopRequireDefault(require("../../../../app/selectors/selectSegmentsExperienceId"));

    var _index2 = require("../../../../app/store/index");

    var _updateFragmentConfiguration = _interopRequireDefault(require("../../../../app/thunks/updateFragmentConfiguration"));

    var _getResponsiveConfig = require("../../../../app/utils/getResponsiveConfig");

    var _index3 = require("../../../../prop-types/index");

    var _CommonStyles = require("./CommonStyles");

    var _FieldSet = require("./FieldSet");

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    var FragmentStylesPanel = function FragmentStylesPanel(_ref) {
      var item = _ref.item;
      var dispatch = (0, _index2.useDispatch)();
      var availableViewportSizes = _index.config.availableViewportSizes;
      var fragmentEntryLink = (0, _index2.useSelectorCallback)(function (state) {
        return state.fragmentEntryLinks[item.config.fragmentEntryLinkId];
      }, [item.config.fragmentEntryLinkId]);
      var segmentsExperienceId = (0, _index2.useSelector)(_selectSegmentsExperienceId.default);
      var selectedViewportSize = (0, _index2.useSelector)(function (state) {
        return state.selectedViewportSize;
      });
      var viewportSize = availableViewportSizes[selectedViewportSize];
      var itemConfig = (0, _getResponsiveConfig.getResponsiveConfig)(item.config, selectedViewportSize);
      var onCustomStyleValueSelect = (0, _react.useCallback)(function (name, value) {
        var configurationValues = getConfigurationValues(fragmentEntryLink);

        var nextConfigurationValues = _objectSpread(_objectSpread({}, configurationValues), {}, _defineProperty({}, name, value));

        dispatch((0, _updateFragmentConfiguration.default)({
          configurationValues: nextConfigurationValues,
          fragmentEntryLink: fragmentEntryLink,
          segmentsExperienceId: segmentsExperienceId
        }));
      }, [dispatch, fragmentEntryLink, segmentsExperienceId]);
      return (/*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("p", {
          className: "page-editor__row-styles-panel__viewport-label"
        }, /*#__PURE__*/_react.default.createElement(_icon.default, {
          className: "mr-2",
          symbol: viewportSize.icon
        }), viewportSize.label), selectedViewportSize === _viewportSizes.VIEWPORT_SIZES.desktop && /*#__PURE__*/_react.default.createElement(CustomStyles, {
          fragmentEntryLink: fragmentEntryLink,
          onValueSelect: onCustomStyleValueSelect
        }), /*#__PURE__*/_react.default.createElement(_CommonStyles.CommonStyles, {
          commonStylesValues: itemConfig.styles,
          item: item
        }))
      );
    };

    exports.FragmentStylesPanel = FragmentStylesPanel;

    var CustomStyles = function CustomStyles(_ref2) {
      var _fragmentEntryLink$co, _fragmentEntryLink$co2;

      var fragmentEntryLink = _ref2.fragmentEntryLink,
          onValueSelect = _ref2.onValueSelect;
      var fieldSets = (_fragmentEntryLink$co = fragmentEntryLink.configuration) === null || _fragmentEntryLink$co === void 0 ? void 0 : (_fragmentEntryLink$co2 = _fragmentEntryLink$co.fieldSets) === null || _fragmentEntryLink$co2 === void 0 ? void 0 : _fragmentEntryLink$co2.filter(function (fieldSet) {
        return fieldSet.configurationRole === _fragmentConfigurationRoles.FRAGMENT_CONFIGURATION_ROLES.style;
      });
      return (fieldSets === null || fieldSets === void 0 ? void 0 : fieldSets.length) ? /*#__PURE__*/_react.default.createElement("div", {
        className: "page-editor__page-structure__section__custom-styles"
      }, /*#__PURE__*/_react.default.createElement("h1", {
        className: "sr-only"
      }, Liferay.Language.get('custom-styles')), fieldSets.map(function (fieldSet, index) {
        return (/*#__PURE__*/_react.default.createElement(_FieldSet.FieldSet, {
            fields: fieldSet.fields,
            key: index,
            label: fieldSet.label,
            onValueSelect: onValueSelect,
            values: getConfigurationValues(fragmentEntryLink)
          })
        );
      })) : null;
    };

    function getConfigurationValues(fragmentEntryLink) {
      return _objectSpread(_objectSpread({}, fragmentEntryLink.defaultConfigurationValues), fragmentEntryLink.editableValues[_freemarkerFragmentEntryProcessor.FREEMARKER_FRAGMENT_ENTRY_PROCESSOR]);
    }
    //# sourceMappingURL=FragmentStylesPanel.js.map
  }
});
//# sourceMappingURL=FragmentStylesPanel.js.map
